# SPDX-FileCopyrightText: 2017-2022 Tobias Leupold <tl at stonemx dot de>
#
# SPDX-License-Identifier: BSD-3-Clause

if (EXISTS "${BASE_DIR}/.git")
    find_package(Git QUIET)
endif()

set(RSTFILE "${BASE_DIR}/doc/Readme.rst")
set(CSSFILE "${BASE_DIR}/doc/Readme.css")

if (GIT_FOUND)
    execute_process(COMMAND ${GIT_EXECUTABLE} --no-pager log -1 --format=%ad
                            --date=format:%d.%m.%Y -- ${RSTFILE}
                    OUTPUT_VARIABLE LASTCHANGE
                    OUTPUT_STRIP_TRAILING_WHITESPACE)
    include(${CMAKE_CURRENT_LIST_DIR}/GitDescription.cmake)
    git_get_description(VERSION GIT_ARGS)
    message(STATUS "Setting the Readme's last changed date to ${LASTCHANGE}")
    configure_file(${RSTFILE} ${CMAKE_BINARY_DIR}/Readme.rst)
    set(RSTFILE "Readme.rst")
else()
    message(STATUS "Using the released RST Readme")
endif()

# On some machines, minimal.css is not found without an absolute path.
# We thus try to provide an absolute path.

# First, we try to find minimal.css in /usr/share, where e.g. Debian puts it
set(MINIMALCSS "/usr/share/docutils/writers/html5_polyglot/minimal.css")

# Then, we check if it's in the same directory as the code itself, like on Gentoo
if (NOT EXISTS "${MINIMALCSS}")
    execute_process(COMMAND python3 -c "import docutils; print(docutils.__path__[0])"
                    OUTPUT_VARIABLE DOCUTILSROOT
                    OUTPUT_STRIP_TRAILING_WHITESPACE)
    set(MINIMALCSS "${DOCUTILSROOT}/writers/html5_polyglot/minimal.css")
endif()

# If it's still not found, we simply reference the file without a full path
# ... and continue with fingers crossed ;-)
if (NOT EXISTS "${MINIMALCSS}")
    set(MINIMALCSS "minimal.css")
endif()

message(STATUS "Converting the Readme from RST to HTML")
execute_process(COMMAND ${RST2HTML5} --stylesheet=${MINIMALCSS},${CSSFILE}
                        "${RSTFILE}" "share/muckturnier/Readme.html"
                WORKING_DIRECTORY ${CMAKE_BINARY_DIR})
