// SPDX-FileCopyrightText: 2010-2022 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef RANKINGPAGE_H
#define RANKINGPAGE_H

// Local includes
#include "SharedObjects/Database.h"

// Qt includes
#include <QWidget>
#include <QMap>

// Qt classes
class QGroupBox;
class QLabel;
class QTableWidget;
class QAction;
class QComboBox;
class QPushButton;

// Local classes
class SharedObjects;
class SearchEngine;
class SearchWidget;
class TournamentSettings;

class RankingPage : public QWidget
{
    Q_OBJECT

public:
    explicit RankingPage(QWidget *parent, SharedObjects *sharedObjects);
    void setupGui();
    void reload(int upToRound = 0);

signals:
    void statusUpdate(const QString &message);
    void scoreChanged();
    void enableExport(bool state);
    void requestPrintRanking();

public slots:
    void dataChanged();
    void resetSearch();

private slots:
    void updateSearch(const QString &searchText);
    void includeOpponentGoalsChanged();
    void grayOutUnimportantGoalsChanged();

private: // Functions
    void grayOutUnimportantGoals(const QVector<Database::RankData> &ranking);
    QColor grayedOutColor(const QColor &color);

private: // Variables
    Database *m_db;
    SearchEngine *m_searchEngine;
    TournamentSettings *m_tournamentSettings;

    QAction *m_includeOpponentGoals;
    QAction *m_grayOutUnimportantGoals;

    QGroupBox *m_settingsBox;
    QPushButton *m_printButton;
    QGroupBox *m_rankingBox;
    QLabel *m_interimLabel;
    QLabel *m_noResultsLabel;
    QTableWidget *m_ranking;
    SearchWidget *m_searchWidget;
    QLabel *m_isSearchLabel;
    QComboBox *m_upToRound;
    QLabel *m_upToRoundLabel;
    QLabel *m_multipleRanks;
    QLabel *m_disqualifiedPlayers;

    // This is the cache for the grayed out colors.
    // We can't use a QColor as a QHash key, therefore, it's QRgb/uint representation is used
    QHash<QRgb, QColor> m_grayedOutColors;

};

#endif // RANKINGPAGE_H
