// SPDX-FileCopyrightText: 2019-2022 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

// Local includes

#include "FileNameTemplatePage.h"

#include "SharedObjects/Settings.h"

#include "shared/DefaultValues.h"

// Qt includes
#include <QDebug>
#include <QVBoxLayout>
#include <QLabel>
#include <QLineEdit>
#include <QPushButton>
#include <QDateTime>
#include <QMessageBox>

FileNameTemplatePage::FileNameTemplatePage(Settings *settings, QWidget *parent)
    : AbstractSettingsPage(tr("Vorlage Datenbankdateiname"), parent),
      m_settings(settings)
{
    QLabel *fileNameTemplateLabel = new QLabel(tr("Für neue Turnierdatenbanken wird der Dateiname "
                                                  "aufgrund folgender Vorlage voreingestellt:"));
    fileNameTemplateLabel->setWordWrap(true);
    layout()->addWidget(fileNameTemplateLabel);

    m_template = new QLineEdit;
    connect(m_template, &QLineEdit::textChanged, this, &FileNameTemplatePage::updateParsedFileName);
    layout()->addWidget(m_template);

    m_parsedFileName = new QLabel;
    layout()->addWidget(m_parsedFileName);

    m_template->setText(m_settings->dbFileNameTemplate());

    QLabel *formatCommentLabel = new QLabel(tr("Es können Teile des aktuellen Datums und/oder der "
                                               "aktuellen Zeit eingefügt werden. "
                                               "<a href=\"#info\">Wie funktioniert das?</a>"));
    formatCommentLabel->setWordWrap(true);
    formatCommentLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
    layout()->addWidget(formatCommentLabel);
    connect(formatCommentLabel, &QLabel::linkActivated,
            this, &FileNameTemplatePage::showFileNameTemplateInfo);

    layout()->addStretch();

    QHBoxLayout *controlLayout = new QHBoxLayout;
    layout()->addLayout(controlLayout);
    controlLayout->addStretch();
    QPushButton *restoreTemplateButton = new QPushButton(tr("Zurücksetzen"));
    connect(restoreTemplateButton, &QPushButton::clicked,
            this, &FileNameTemplatePage::restoreTemplate);
    controlLayout->addWidget(restoreTemplateButton);
}

void FileNameTemplatePage::updateParsedFileName(const QString &text)
{
    m_parsedFileName->setText(tr("Geparste Vorlage: „%1.mtdb“").arg(
                                 QDateTime::currentDateTime().toString(text.simplified())));
}

void FileNameTemplatePage::showFileNameTemplateInfo(const QString &)
{
    QMessageBox::information(this, tr("Vorlage für Datenbankdateinamen"),
        tr("<p>Zum Parsen (Übersetzen/Umsetzen) der Vorlage wird die Funktion "
           "<kbd>QDateTime::toString()</kbd> benutzt. Die genaue Syntax ist in der "
           "<a href=\"https://doc.qt.io/qt-5/qdatetime.html#toString\">Dokumentation zu "
           "<kbd>QDateTime</kbd></a> beschrieben.</p>"
           "<p>Für diesen Einsatzzweck am relevantesten:</p>"
           "<ul>"
           "<li>Alles in einfachen Anführungszeichen <kbd>'</kbd> wird genau so angezeigt</li>"
           "<li><kbd>yy</kbd> bzw. <kbd>yyyy</kbd> wird mit der aktuellen Jahreszahl ersetzt</li>"
           "<li><kbd>M</kbd> bis <kbd>MMMM</kbd> wird mit dem aktuellen Monat ersetzt</li>"
           "</ul>"));
}

void FileNameTemplatePage::restoreTemplate()
{
    m_template->setText(DefaultValues::dbFileNameTemplate);
}

void FileNameTemplatePage::saveSettings()
{
    const QString templateText = m_template->text().simplified();
    m_settings->saveDbFileNameTemplate(templateText.isEmpty() ? DefaultValues::dbFileNameTemplate
                                                              : templateText);
}
