// SPDX-FileCopyrightText: 2020-2022 Tobias Leupold <tl at stonemx dot de>
//
// SPDX-License-Identifier: GPL-3.0-or-later

#ifndef MARKERS_H
#define MARKERS_H

#include <QString>
#include <QColor>
#include <QHash>

namespace Markers
{

// Combo boxes / types

enum Type {
    Default,
    Drawn,
    Absent,
    Single,
    Assigned
};

// Markers

enum MarkerSorting {
    NewBlock,
    Merged
};

struct Marker
{
    int id;
    QString name;
    QColor color;
    MarkerSorting sorting;
};

// Singles Management

constexpr int singlesManagementVersion = 1;

struct SinglesManagement
{
    bool enabled;
    int singleMarker;
    bool markSingles;
    QString conditionString;
    int condition;
    int assignedMarker;
};

const SinglesManagement defaultSinglesManagement {
    false,               // enabled
    0,                   // singleMarker
    false,               // markSingles
    QStringLiteral("/"), // conditionString
    0,                   // condition
    0                    // assignedMarker
};

const QVector<Markers::Type> specialMarkers {
    Markers::Default,
    Markers::Drawn,
    Markers::Absent
};

const QHash<Markers::Type, int> defaultSpecialMarkerValues {
    { Markers::Default,  0 },
    { Markers::Drawn,   -1 },
    { Markers::Absent,  -1 }
};

}

#endif // MARKERS_H
